summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/history
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/history')
-rw-r--r--kopete/plugins/history/historydialog.cpp34
-rw-r--r--kopete/plugins/history/historydialog.h8
-rw-r--r--kopete/plugins/history/historyguiclient.cpp2
-rw-r--r--kopete/plugins/history/historyguiclient.h8
-rw-r--r--kopete/plugins/history/historyplugin.cpp2
-rw-r--r--kopete/plugins/history/historyplugin.h2
-rw-r--r--kopete/plugins/history/historyviewer.ui4
7 files changed, 30 insertions, 30 deletions
diff --git a/kopete/plugins/history/historydialog.h b/kopete/plugins/history/historydialog.h
index 4df323d6..daa45362 100644
--- a/kopete/plugins/history/historydialog.h
+++ b/kopete/plugins/history/historydialog.h
@@ -40,7 +40,7 @@ class KURL;
namespace KParts { struct URLArgs; class Part; }
-class KListViewDateItem;
+class TDEListViewDateItem;
class DMPair
{
@@ -117,7 +117,7 @@ class HistoryDialog : public KDialogBase
/**
* Search if @param item already has @param text child
*/
- bool hasChild(KListViewItem* item, int month);
+ bool hasChild(TDEListViewItem* item, int month);
/**
* We show history dialog to look at the log for a metacontact. Here is this metacontact.
@@ -139,8 +139,8 @@ class HistoryDialog : public KDialogBase
bool mSearching;
- KAction *mCopyAct;
- KAction *mCopyURLAct;
+ TDEAction *mCopyAct;
+ TDEAction *mCopyURLAct;
TQString mURL;
};
diff --git a/kopete/plugins/history/historyguiclient.cpp b/kopete/plugins/history/historyguiclient.cpp
index 4b1798ae..21bde3b5 100644
--- a/kopete/plugins/history/historyguiclient.cpp
+++ b/kopete/plugins/history/historyguiclient.cpp
@@ -41,7 +41,7 @@ HistoryGUIClient::HistoryGUIClient(Kopete::ChatSession *parent, const char *name
TQPtrList<Kopete::Contact> mb=m_manager->members();
m_logger=new HistoryLogger( mb.first() , this );
- actionLast=new KAction( i18n("History Last" ), TQString::fromLatin1( "finish" ), 0, this, TQT_SLOT(slotLast()), actionCollection() , "historyLast" );
+ actionLast=new TDEAction( i18n("History Last" ), TQString::fromLatin1( "finish" ), 0, this, TQT_SLOT(slotLast()), actionCollection() , "historyLast" );
actionPrev = KStdAction::back( this, TQT_SLOT(slotPrevious()), actionCollection() , "historyPrevious" );
actionNext = KStdAction::forward( this, TQT_SLOT(slotNext()), actionCollection() , "historyNext" );
diff --git a/kopete/plugins/history/historyguiclient.h b/kopete/plugins/history/historyguiclient.h
index 356afe29..86c4ae21 100644
--- a/kopete/plugins/history/historyguiclient.h
+++ b/kopete/plugins/history/historyguiclient.h
@@ -21,7 +21,7 @@
namespace Kopete { class ChatSession; }
class HistoryLogger;
-class KAction;
+class TDEAction;
/**
*@author Olivier Goffart
@@ -48,9 +48,9 @@ private:
//int m_nbAutoChatWindow;
//unsigned int m_nbChatWindow;
- KAction *actionPrev;
- KAction *actionNext;
- KAction *actionLast;
+ TDEAction *actionPrev;
+ TDEAction *actionNext;
+ TDEAction *actionLast;
};
#endif
diff --git a/kopete/plugins/history/historyplugin.cpp b/kopete/plugins/history/historyplugin.cpp
index c9dc5fd6..d4791952 100644
--- a/kopete/plugins/history/historyplugin.cpp
+++ b/kopete/plugins/history/historyplugin.cpp
@@ -44,7 +44,7 @@ K_EXPORT_COMPONENT_FACTORY( kopete_history, HistoryPluginFactory( &aboutdata )
HistoryPlugin::HistoryPlugin( TQObject *parent, const char *name, const TQStringList & /* args */ )
: Kopete::Plugin( HistoryPluginFactory::instance(), parent, name ), m_loggerFactory( this )
{
- KAction *viewMetaContactHistory = new KAction( i18n("View &History" ),
+ TDEAction *viewMetaContactHistory = new TDEAction( i18n("View &History" ),
TQString::fromLatin1( "history" ), 0, this, TQT_SLOT(slotViewHistory()),
actionCollection(), "viewMetaContactHistory" );
viewMetaContactHistory->setEnabled(
diff --git a/kopete/plugins/history/historyplugin.h b/kopete/plugins/history/historyplugin.h
index 85aa2a3e..d20a28c9 100644
--- a/kopete/plugins/history/historyplugin.h
+++ b/kopete/plugins/history/historyplugin.h
@@ -28,7 +28,7 @@
#include "kopetemessagehandler.h"
class KopeteView;
-class KActionCollection;
+class TDEActionCollection;
namespace Kopete
{
diff --git a/kopete/plugins/history/historyviewer.ui b/kopete/plugins/history/historyviewer.ui
index 8d7ca4b2..6711dd31 100644
--- a/kopete/plugins/history/historyviewer.ui
+++ b/kopete/plugins/history/historyviewer.ui
@@ -145,7 +145,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="KListViewSearchLine">
+ <widget class="TDEListViewSearchLine">
<property name="name">
<cstring>dateSearchLine</cstring>
</property>
@@ -173,7 +173,7 @@
</size>
</property>
</widget>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Date</string>
diff --git a/kopete/plugins/history/historydialog.cpp b/kopete/plugins/history/historydialog.cpp
index 1dd63cc3..992d586f 100644
--- a/kopete/plugins/history/historydialog.cpp
+++ b/kopete/plugins/history/historydialog.cpp
@@ -57,10 +57,10 @@
#include <kstdaction.h>
#include <kaction.h>
-class KListViewDateItem : public KListViewItem
+class TDEListViewDateItem : public TDEListViewItem
{
public:
- KListViewDateItem(KListView* parent, TQDate date, Kopete::MetaContact *mc);
+ TDEListViewDateItem(TDEListView* parent, TQDate date, Kopete::MetaContact *mc);
TQDate date() { return mDate; }
Kopete::MetaContact *metaContact() { return mMetaContact; }
@@ -73,20 +73,20 @@ private:
-KListViewDateItem::KListViewDateItem(KListView* parent, TQDate date, Kopete::MetaContact *mc)
- : KListViewItem(parent, date.toString(Qt::ISODate), mc->displayName())
+TDEListViewDateItem::TDEListViewDateItem(TDEListView* parent, TQDate date, Kopete::MetaContact *mc)
+ : TDEListViewItem(parent, date.toString(Qt::ISODate), mc->displayName())
{
mDate = date;
mMetaContact = mc;
}
-int KListViewDateItem::compare(TQListViewItem *i, int col, bool ascending) const
+int TDEListViewDateItem::compare(TQListViewItem *i, int col, bool ascending) const
{
if (col)
return TQListViewItem::compare(i, col, ascending);
//compare dates - do NOT use ascending var here
- KListViewDateItem* item = static_cast<KListViewDateItem*>(i);
+ TDEListViewDateItem* item = static_cast<TDEListViewDateItem*>(i);
if ( mDate < item->date() )
return -1;
return ( mDate > item->date() );
@@ -173,9 +173,9 @@ HistoryDialog::HistoryDialog(Kopete::MetaContact *mc, TQWidget* parent,
connect(mHtmlPart, TQT_SIGNAL(popupMenu(const TQString &, const TQPoint &)), this, TQT_SLOT(slotRightClick(const TQString &, const TQPoint &)));
//initActions
- KActionCollection* ac = new KActionCollection(this);
+ TDEActionCollection* ac = new TDEActionCollection(this);
mCopyAct = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), ac );
- mCopyURLAct = new KAction( i18n( "Copy Link Address" ), TQString::fromLatin1( "editcopy" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotCopyURL() ), ac );
+ mCopyURLAct = new TDEAction( i18n( "Copy Link Address" ), TQString::fromLatin1( "editcopy" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotCopyURL() ), ac );
resize(650, 700);
centerOnScreen(this);
@@ -232,7 +232,7 @@ void HistoryDialog::slotLoadDays()
{
TQDate c2Date(pair.date().year(),pair.date().month(),dayList[i]);
if (mInit.dateMCList.find(pair) == mInit.dateMCList.end())
- new KListViewDateItem(mMainWidget->dateListView, c2Date, pair.metaContact());
+ new TDEListViewDateItem(mMainWidget->dateListView, c2Date, pair.metaContact());
}
mMainWidget->searchProgress->advance(1);
TQTimer::singleShot(0,this,TQT_SLOT(slotLoadDays()));
@@ -319,7 +319,7 @@ void HistoryDialog::init(Kopete::Contact *c)
void HistoryDialog::dateSelected(TQListViewItem* it)
{
- KListViewDateItem *item = static_cast<KListViewDateItem*>(it);
+ TDEListViewDateItem *item = static_cast<TDEListViewDateItem*>(it);
if (!item) return;
@@ -420,11 +420,11 @@ void HistoryDialog::slotSearchTextChanged(const TQString& searchText)
void HistoryDialog::listViewShowElements(bool s)
{
- KListViewDateItem* item = static_cast<KListViewDateItem*>(mMainWidget->dateListView->firstChild());
+ TDEListViewDateItem* item = static_cast<TDEListViewDateItem*>(mMainWidget->dateListView->firstChild());
while (item != 0)
{
item->setVisible(s);
- item = static_cast<KListViewDateItem*>(item->nextSibling());
+ item = static_cast<TDEListViewDateItem*>(item->nextSibling());
}
}
@@ -440,7 +440,7 @@ void HistoryDialog::slotSearchErase()
* How does the search work
* ------------------------
* We do the search respecting the current metacontact filter item. To do this, we iterate over the
* elements in the KListView (KListViewDateItems) and, for each one, we iterate over its subcontacts,
* manually searching the log files of each one. To avoid searching files twice, the months that have
* been searched already are stored in searchedMonths. The matches are placed in the matches TQMap.
* Finally, the current date item is checked in the matches TQMap, and if it is present, it is shown.
@@ -472,9 +472,9 @@ void HistoryDialog::slotSearch()
mSearching = true;
// iterate over items in the date list widget
- for(KListViewDateItem *curItem = static_cast<KListViewDateItem*>(mMainWidget->dateListView->firstChild());
+ for(TDEListViewDateItem *curItem = static_cast<TDEListViewDateItem*>(mMainWidget->dateListView->firstChild());
curItem != 0;
- curItem = static_cast<KListViewDateItem *>(curItem->nextSibling())
+ curItem = static_cast<TDEListViewDateItem *>(curItem->nextSibling())
)
{
tqApp->processEvents();
@@ -574,8 +574,8 @@ void HistoryDialog::doneProgressBar()
void HistoryDialog::slotRightClick(const TQString &url, const TQPoint &point)
{
- KPopupMenu *chatWindowPopup = 0L;
- chatWindowPopup = new KPopupMenu();
+ TDEPopupMenu *chatWindowPopup = 0L;
+ chatWindowPopup = new TDEPopupMenu();
if ( !url.isEmpty() )
{
@@ -440,7 +440,7 @@ void HistoryDialog::slotSearchErase()
* ------------------------
* We do the search respecting the current metacontact filter item. To do this, we iterate over the
-* elements in the KListView (KListViewDateItems) and, for each one, we iterate over its subcontacts,
+* elements in the TDEListView (TDEListViewDateItems) and, for each one, we iterate over its subcontacts,
* manually searching the log files of each one. To avoid searching files twice, the months that have
* been searched already are stored in searchedMonths. The matches are placed in the matches TQMap.